@@ -1,11 +1,11 @@
 package Test::Smoke;
 use strict;
 
-use vars qw($VERSION $conf @EXPORT);
-$VERSION  = "1.80_06";
+use vars qw($conf);
+our $VERSION  = "1.81_01";
 
 use base 'Exporter';
-@EXPORT  = qw( $conf &read_config &run_smoke );
+our @EXPORT  = qw( $conf &read_config &run_smoke );
 
 my $ConfigError;
 
