@@ -2,7 +2,7 @@ package Test::Smoke::App::Options;
 use warnings;
 use strict;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use Test::Smoke::App::AppOption;
 
@@ -105,6 +105,7 @@ sub poster_config { # posting to CoreSmokeDB
             ddir(),
             smokedb_url(),
             jsnfile(),
+            qfile(),
             report(0),
         ],
         special_options => {
@@ -135,6 +136,7 @@ sub reporter_config { # needed for sending out reports
             showcfg(),
             locale(),
             defaultenv(),
+            perlio_only(),
             is56x(),
             skip_tests(),
             harnessonly(),
@@ -204,6 +206,7 @@ sub runsmoke_config { # runsmoke.pl
             jsnfile(),
             cfg(),
             defaultenv(),
+            perlio_only(),
             force_c_locale(),
             harness3opts(),
             harnessonly(),
@@ -314,6 +317,20 @@ sub smokestatus_config {
     );
 }
 
+sub handlequeue_config {
+    my %pc = poster_config();
+    my $pc_so = $pc{special_options};
+    return (
+        main_options => [ poster() ],
+        general_options => [
+            adir(),
+            smokedb_url(),
+            qfile(),
+        ],
+        special_options => $pc_so,
+    );
+}
+
 ###########################################################
 #####              Individual options                 #####
 ###########################################################
@@ -926,6 +943,19 @@ sub perl5opt {
     );
 }
 
+sub perlio_only {
+    return $opt->new(
+        name       => 'perlio_only',
+        option     => '!',
+        default    => 0,
+        helptext   => "Do not set the test suite environment to stdio.",
+        configtext => "Run the test suite without \$ENV{PERLIO}=='stdio'?",
+        configtype => 'prompt_yn',
+        configalt  => sub { [qw/ N y /] },
+        configdft  => sub {'n'},
+    );
+}
+
 sub poster {
     return $opt->new(
         name       => 'poster',
@@ -940,6 +970,19 @@ sub poster {
     );
 }
 
+sub qfile {
+    return $opt->new(
+        name       => 'qfile',
+        option     => '=s',
+        allow      => [undef, '', qr{^[\w./\\-]+$}],
+        default    => undef,
+        helptext   => 'The qfile keeps the queue of reports to resend.',
+        configtext => "One can now queue reports if they couldn't be delevered.\n"
+                    . "\tLeave empty for no queue.",
+        configdft => sub {undef},
+    );
+}
+
 sub report {
     my $default = @_ ? shift : 1;
     return $opt->new(
@@ -1097,7 +1140,7 @@ sub smartsmoke {
 }
 
 sub smokedb_url {
-    my $default = 'https://perl5.test-smoke.org/report';
+    my $default = 'https://perl5.test-smoke.org/api/report';
     return $opt->new(
         name       => 'smokedb_url',
         option     => '=s',
